@@ -84,7 +84,7 @@ CubeEffectConfig::CubeEffectConfig(QWidget* parent, const QVariantList& args) :
     m_ui->editor->addCollection(m_actionCollection);
 
     capsSelectionChanged();
-    connect(m_ui->kcfg_Caps, SIGNAL(stateChanged(int)), this, SLOT(capsSelectionChanged()));
+    connect(m_ui->kcfg_Caps, &QCheckBox::stateChanged, this, &CubeEffectConfig::capsSelectionChanged);
     m_ui->kcfg_Wallpaper->setFilter(QStringLiteral("*.png *.jpeg *.jpg "));
     CubeConfig::instance(KWIN_CONFIG);
     addConfig(CubeConfig::self(), m_ui);
