@@ -61,7 +61,7 @@ static QList<QByteArray> glExtensions;
 
 // Functions
 
-void initGL(std::function<resolveFuncPtr(const char*)> resolveFunction)
+void initGL(const std::function<resolveFuncPtr(const char*)> &resolveFunction)
 {
     // Get list of supported OpenGL extensions
     if (hasGLVersion(3, 0)) {
@@ -209,7 +209,7 @@ bool GLShader::link()
     glGetProgramiv(mProgram, GL_LINK_STATUS, &status);
 
     if (status == 0) {
-        qCCritical(LIBKWINGLUTILS) << "Failed to link shader:" << endl << log;
+        qCCritical(LIBKWINGLUTILS) << "Failed to link shader:" << "\n" << log;
         mValid = false;
     } else if (length > 0) {
         qCDebug(LIBKWINGLUTILS) << "Shader link log:" << log;
@@ -261,7 +261,7 @@ bool GLShader::compile(GLuint program, GLenum shaderType, const QByteArray &sour
 
     if (status == 0) {
         const char *typeName = (shaderType == GL_VERTEX_SHADER ? "vertex" : "fragment");
-        qCCritical(LIBKWINGLUTILS) << "Failed to compile" << typeName << "shader:" << endl << log;
+        qCCritical(LIBKWINGLUTILS) << "Failed to compile" << typeName << "shader:" << "\n" << log;
     } else if (length > 0)
         qCDebug(LIBKWINGLUTILS) << "Shader compile log:" << log;
 
@@ -347,6 +347,7 @@ void GLShader::resolveLocations()
     mFloatLocation[Saturation]    = uniformLocation("saturation");
 
     mColorLocation[Color] = uniformLocation("geometryColor");
+    mVec4Location[TextureClamp] = uniformLocation("textureClamp");
 
     mLocationsResolved = true;
 }
@@ -877,14 +878,24 @@ QByteArray ShaderManager::generateFragmentSource(ShaderTraits traits) const
     } else if (traits & ShaderTrait::UniformColor)
         stream << "uniform vec4 geometryColor;\n";
 
+    if (traits & ShaderTrait::ClampTexture) {
+        stream << "uniform vec4 textureClamp;\n";
+    }
+
     if (output != QByteArrayLiteral("gl_FragColor"))
         stream << "\nout vec4 " << output << ";\n";
 
     stream << "\nvoid main(void)\n{\n";
     if (traits & ShaderTrait::MapTexture) {
-        if (traits & (ShaderTrait::Modulate | ShaderTrait::AdjustSaturation)) {
-            stream << "    vec4 texel = " << textureLookup << "(sampler, texcoord0);\n";
+        stream << "vec2 texcoordC = texcoord0;\n";
 
+        if (traits & ShaderTrait::ClampTexture) {
+            stream << "texcoordC.x = clamp(texcoordC.x, textureClamp.x, textureClamp.z);\n";
+            stream << "texcoordC.y = clamp(texcoordC.y, textureClamp.y, textureClamp.w);\n";
+        }
+
+        if (traits & (ShaderTrait::Modulate | ShaderTrait::AdjustSaturation)) {
+            stream << "    vec4 texel = " << textureLookup << "(sampler, texcoordC);\n";
             if (traits & ShaderTrait::Modulate)
                 stream << "    texel *= modulation;\n";
             if (traits & ShaderTrait::AdjustSaturation)
@@ -892,7 +903,7 @@ QByteArray ShaderManager::generateFragmentSource(ShaderTraits traits) const
 
             stream << "    " << output << " = texel;\n";
         } else {
-            stream << "    " << output << " = " << textureLookup << "(sampler, texcoord0);\n";
+            stream << "    " << output << " = " << textureLookup << "(sampler, texcoordC);\n";
         }
     } else if (traits & ShaderTrait::UniformColor)
         stream << "    " << output << " = geometryColor;\n";
@@ -1515,7 +1526,7 @@ public:
     IndexBuffer();
     ~IndexBuffer();
 
-    void accomodate(int count);
+    void accommodate(int count);
     void bind();
 
 private:
@@ -1541,7 +1552,7 @@ IndexBuffer::~IndexBuffer()
     glDeleteBuffers(1, &m_buffer);
 }
 
-void IndexBuffer::accomodate(int count)
+void IndexBuffer::accommodate(int count)
 {
     // Check if we need to grow the buffer.
     if (count <= m_count)
@@ -2162,7 +2173,7 @@ void GLVertexBuffer::draw(const QRegion &region, GLenum primitiveMode, int first
             indexBuffer = new IndexBuffer;
 
         indexBuffer->bind();
-        indexBuffer->accomodate(count / 4);
+        indexBuffer->accommodate(count / 4);
 
         count = count * 6 / 4;
 
