@@ -52,7 +52,7 @@ class GLVertexBufferPrivate;
 //  well as checking for GL version and extensions
 //  Note that GL context has to be created by the time this function is called
 typedef void (*resolveFuncPtr)();
-void KWINGLUTILS_EXPORT initGL(std::function<resolveFuncPtr(const char*)> resolveFunction);
+void KWINGLUTILS_EXPORT initGL(const std::function<resolveFuncPtr(const char*)> &resolveFunction);
 // Cleans up all resources hold by the GL Context
 void KWINGLUTILS_EXPORT cleanupGL();
 
@@ -109,7 +109,7 @@ public:
     /**
      * @return The value of the uniform as a matrix
      * @since 4.7
-     **/
+     */
     QMatrix4x4 getUniformMatrix4x4(const char* name);
 
     enum MatrixUniform {
@@ -129,6 +129,7 @@ public:
 
     enum Vec4Uniform {
         ModulationConstant,
+        TextureClamp,
         Vec4UniformCount
     };
 
@@ -186,6 +187,7 @@ enum class ShaderTrait {
     UniformColor     = (1 << 1),
     Modulate         = (1 << 2),
     AdjustSaturation = (1 << 3),
+    ClampTexture     = (1 << 4),
 };
 
 Q_DECLARE_FLAGS(ShaderTraits, ShaderTrait)
@@ -201,36 +203,36 @@ Q_DECLARE_FLAGS(ShaderTraits, ShaderTrait)
  *
  * @author Martin Gräßlin <mgraesslin@kde.org>
  * @since 4.7
- **/
+ */
 class KWINGLUTILS_EXPORT ShaderManager
 {
 public:
     /**
      * Returns a shader with the given traits, creating it if necessary.
-     **/
+     */
     GLShader *shader(ShaderTraits traits);
 
     /**
      * @return The currently bound shader or @c null if no shader is bound.
-     **/
+     */
     GLShader *getBoundShader() const;
 
     /**
      * @return @c true if a shader is bound, @c false otherwise
-     **/
+     */
     bool isShaderBound() const;
     /**
      * Is @c true if the environment variable KWIN_GL_DEBUG is set to 1.
      * In that case shaders are compiled with KWIN_SHADER_DEBUG defined.
      * @returns @c true if shaders are compiled with debug information
      * @since 4.8
-     **/
+     */
     bool isShaderDebug() const;
 
     /**
      * Pushes the current shader onto the stack and binds a shader
      * with the given traits.
-     **/
+     */
     GLShader *pushShader(ShaderTraits traits);
 
     /**
@@ -239,7 +241,7 @@ public:
      * To bind a built-in shader use the more specific method.
      * @param shader The shader to be bound
      * @see popShader
-     **/
+     */
     void pushShader(GLShader *shader);
 
     /**
@@ -248,7 +250,7 @@ public:
      * It is not safe to call this method if there is no bound shader.
      * @see pushShader
      * @see getBoundShader
-     **/
+     */
     void popShader();
 
     /**
@@ -257,7 +259,7 @@ public:
      * @param vertexSource The source code of the vertex shader
      * @param fragmentSource The source code of the fragment shader.
      * @return The created shader
-     **/
+     */
     GLShader *loadShaderFromCode(const QByteArray &vertexSource, const QByteArray &fragmentSource);
 
     /**
@@ -275,7 +277,7 @@ public:
      * @param fragmentSource optional fragment shader source code to be used instead of shader traits
      * @return new generated shader
      * @since 5.6
-     **/
+     */
     GLShader *generateCustomShader(ShaderTraits traits, const QByteArray &vertexSource = QByteArray(), const QByteArray &fragmentSource = QByteArray());
 
     /**
@@ -298,23 +300,23 @@ public:
      * @return new generated shader
      * @see generateCustomShader
      * @since 5.6
-     **/
+     */
     GLShader *generateShaderFromResources(ShaderTraits traits, const QString &vertexFile = QString(), const QString &fragmentFile = QString());
 
     /**
      * Compiles and tests the dynamically generated shaders.
      * Returns true if successful and false otherwise.
-     **/
+     */
     bool selfTest();
 
     /**
      * @return a pointer to the ShaderManager instance
-     **/
+     */
     static ShaderManager *instance();
 
     /**
      * @internal
-     **/
+     */
     static void cleanup();
 
 private:
@@ -350,7 +352,7 @@ private:
  * @endcode
  *
  * @since 4.10
- **/
+ */
 class KWINGLUTILS_EXPORT ShaderBinder
 {
 public:
@@ -359,7 +361,7 @@ public:
      *
      * @param shader The Shader to push on the stack
      * @see ShaderManager::pushShader
-     **/
+     */
     explicit ShaderBinder(GLShader *shader);
     /**
      * @brief Pushes the Shader with the given @p traits to the ShaderManager's stack.
@@ -367,13 +369,13 @@ public:
      * @param traits The traits describing the shader
      * @see ShaderManager::pushShader
      * @since 5.6
-     **/
+     */
     explicit ShaderBinder(ShaderTraits traits);
     ~ShaderBinder();
 
     /**
      * @return The Shader pushed to the Stack.
-     **/
+     */
     GLShader *shader();
 
 private:
@@ -413,20 +415,20 @@ GLShader* ShaderBinder::shader()
  *  later be used to e.g. do post-processing of the scene.
  *
  * @author Rivo Laks <rivolaks@hot.ee>
- **/
+ */
 class KWINGLUTILS_EXPORT GLRenderTarget
 {
 public:
     /**
      * Constructs a GLRenderTarget
      * @since 5.13
-     **/
+     */
     explicit GLRenderTarget();
 
     /**
      * Constructs a GLRenderTarget
      * @param color texture where the scene will be rendered onto
-     **/
+     */
     explicit GLRenderTarget(const GLTexture& color);
     ~GLRenderTarget();
 
@@ -434,25 +436,25 @@ public:
      * Enables this render target.
      * All OpenGL commands from now on affect this render target until the
      *  @ref disable method is called
-     **/
+     */
     bool enable();
     /**
      * Disables this render target, activating whichever target was active
      *  when @ref enable was called.
-     **/
+     */
     bool disable();
 
     /**
      * Sets the target texture
      * @param target texture where the scene will be rendered on
      * @since 4.8
-     **/
+     */
     void attachTexture(const GLTexture& target);
 
     /**
      * Detaches the texture that is currently attached to this framebuffer object.
      * @since 5.13
-     **/
+     */
     void detachTexture();
 
     bool valid() const  {
@@ -472,7 +474,7 @@ public:
      * Pushes the render target stack of the input parameter in reverse order.
      * @param targets The stack of GLRenderTargets
      * @since 5.13
-     **/
+     */
     static void pushRenderTargets(QStack <GLRenderTarget*> targets);
 
     static void pushRenderTarget(GLRenderTarget *target);
@@ -484,7 +486,7 @@ public:
      *
      * @returns whether framebuffer blitting is supported.
      * @since 4.8
-     **/
+     */
     static bool blitSupported();
 
     /**
@@ -497,13 +499,13 @@ public:
      * @param filter The filter to use if blitted content needs to be scaled.
      * @see blitSupported
      * @since 4.8
-     **/
+     */
     void blitFromFramebuffer(const QRect &source = QRect(), const QRect &destination = QRect(), GLenum filter = GL_LINEAR);
 
     /**
      * Sets the virtual screen size to @p s.
      * @since 5.2
-     **/
+     */
     static void setVirtualScreenSize(const QSize &s) {
         s_virtualScreenSize = s;
     }
@@ -514,7 +516,7 @@ public:
      * in the virtual geometry space the rendering geometries use.
      * @see virtualScreenGeometry
      * @since 5.9
-     **/
+     */
     static void setVirtualScreenGeometry(const QRect &g) {
         s_virtualScreenGeometry = g;
     }
@@ -524,7 +526,7 @@ public:
      * in the virtual geometry space the rendering system uses.
      * @see setVirtualScreenGeometry
      * @since 5.9
-     **/
+     */
     static QRect virtualScreenGeometry() {
         return s_virtualScreenGeometry;
     }
@@ -535,7 +537,7 @@ public:
      * @returns the ratio between the virtual geometry space the rendering
      * system uses and the target
      * @since 5.10
-     **/
+     */
     static void setVirtualScreenScale(qreal scale) {
         s_virtualScreenScale = scale;
     }
@@ -578,7 +580,7 @@ enum VertexAttributeType {
  * The attribute format consists of the attribute index, the number of
  * vector components, the data type, and the offset of the first element
  * relative to the start of the vertex data.
- **/
+ */
 struct GLVertexAttrib
 {
     int index;            /** The attribute index */
@@ -599,13 +601,13 @@ struct GLVertexAttrib
  *
  * @author Martin Gräßlin <mgraesslin@kde.org>
  * @since 4.6
- **/
+ */
 class KWINGLUTILS_EXPORT GLVertexBuffer
 {
 public:
     /**
      * Enum to define how often the vertex data in the buffer object changes.
-     **/
+     */
     enum UsageHint {
         Dynamic, ///< frequent changes, but used several times for rendering
         Static, ///< No changes to data
@@ -639,17 +641,17 @@ public:
      *     Vertex vertices[6];
      *     vbo->setAttribLayout(attribs, 2, sizeof(Vertex));
      *     vbo->setData(vertices, sizeof(vertices));
-     **/
+     */
     void setAttribLayout(const GLVertexAttrib *attribs, int count, int stride);
 
     /**
      * Uploads data into the buffer object's data store.
-     **/
+     */
     void setData(const void *data, size_t sizeInBytes);
 
     /**
      * Sets the number of vertices that will be drawn by the render() method.
-     **/
+     */
     void setVertexCount(int count);
 
     /**
@@ -659,7 +661,7 @@ public:
      * @param vertices The vertices, size must equal @a numberVertices * @a dim
      * @param texcoords The texture coordinates for each vertex.
      * Size must equal 2 * @a numberVertices.
-     **/
+     */
     void setData(int numberVertices, int dim, const float* vertices, const float* texcoords);
 
     /**
@@ -679,32 +681,32 @@ public:
      *
      * It is assumed that the GL_ARRAY_BUFFER_BINDING will not be changed while
      * the buffer object is mapped.
-     **/
+     */
     GLvoid *map(size_t size);
 
     /**
      * Flushes the mapped buffer range and unmaps the buffer.
-     **/
+     */
     void unmap();
 
     /**
      * Binds the vertex arrays to the context.
-     **/
+     */
     void bindArrays();
 
     /**
      * Disables the vertex arrays.
-     **/
+     */
     void unbindArrays();
 
     /**
      * Draws count vertices beginning with first.
-     **/
+     */
     void draw(GLenum primitiveMode, int first, int count);
 
     /**
      * Draws count vertices beginning with first.
-     **/
+     */
     void draw(const QRegion &region, GLenum primitiveMode, int first, int count, bool hardwareClipping = false);
 
     /**
@@ -712,12 +714,12 @@ public:
      * Please refer to OpenGL documentation of glDrawArrays or glDrawElements for allowed
      * values for @a primitiveMode. Best is to use GL_TRIANGLES or similar to be future
      * compatible.
-     **/
+     */
     void render(GLenum primitiveMode);
     /**
      * Same as above restricting painting to @a region if @a hardwareClipping is true.
      * It's within the caller's responsibility to enable GL_SCISSOR_TEST.
-     **/
+     */
     void render(const QRegion& region, GLenum primitiveMode, bool hardwareClipping = false);
     /**
      * Sets the color the geometry will be rendered with.
@@ -728,14 +730,14 @@ public:
      * @see setUseColor
      * @see isUseColor
      * @since 4.7
-     **/
+     */
     void setColor(const QColor& color, bool enableColor = true);
     /**
      * @return @c true if geometry will be painted with a color, @c false otherwise
      * @see setUseColor
      * @see setColor
      * @since 4.7
-     **/
+     */
     bool isUseColor() const;
     /**
      * Enables/Disables rendering the geometry with a color.
@@ -744,49 +746,49 @@ public:
      * @see isUseColor
      * @see setColor
      * @since 4.7
-     **/
+     */
     void setUseColor(bool enable);
 
     /**
      * Resets the instance to default values.
      * Useful for shared buffers.
      * @since 4.7
-     **/
+     */
     void reset();
 
     /**
      * Notifies the vertex buffer that we are done painting the frame.
      *
      * @internal
-     **/
+     */
     void endOfFrame();
 
     /**
      * Notifies the vertex buffer that we have posted the frame.
      *
      * @internal
-     **/
+     */
     void framePosted();
 
     /**
      * @internal
-     **/
+     */
     static void initStatic();
 
     /**
      * @internal
-     **/
+     */
     static void cleanup();
 
     /**
      * Returns true if indexed quad mode is supported, and false otherwise.
-     **/
+     */
     static bool supportsIndexedQuads();
 
     /**
      * @return A shared VBO for streaming data
      * @since 4.7
-     **/
+     */
     static GLVertexBuffer *streamingBuffer();
 
     /**
@@ -794,7 +796,7 @@ public:
      * This is the geometry of the OpenGL window currently being rendered to
      * in the virtual geometry space the rendering geometries use.
      * @since 5.9
-     **/
+     */
     static void setVirtualScreenGeometry(const QRect &g) {
         s_virtualScreenGeometry = g;
     }
@@ -805,7 +807,7 @@ public:
      * @returns the ratio between the virtual geometry space the rendering
      * system uses and the target
      * @since 5.11.3
-     **/
+     */
     static void setVirtualScreenScale(qreal s) {
         s_virtualScreenScale = s;
     }
